!-----------------------BEGIN NOTICE -- DO NOT EDIT-----------------------
! NASA Goddard Space Flight Center Land Information System (LIS) v7.1
!
! Copyright (c) 2015 United States Government as represented by the
! Administrator of the National Aeronautics and Space Administration.
! All Rights Reserved.
!-------------------------END NOTICE -- DO NOT EDIT-----------------------
!BOP
! !ROUTINE: noah36_setsoilm
!  \label{noah36_setsoilm}
!
! !REVISION HISTORY:
! 27Feb2005: Sujay Kumar; Initial Specification
! 25Jun2006: Sujay Kumar: Updated for the ESMF design
!
! !INTERFACE:
subroutine noah36_setsoilm(n, LSM_State)
! !USES:
  use ESMF
  use LIS_coreMod, only : LIS_rc
  use LIS_logMod,  only  : LIS_verify, LIS_logunit
  use noah36_lsmMod

  implicit none
! !ARGUMENTS: 
  integer, intent(in)    :: n
  type(ESMF_State)       :: LSM_State
!
! !DESCRIPTION:
!  
!  This routine assigns the soil moisture prognostic variables to noah's
!  model space. 
! 
!EOP

  type(ESMF_Field)       :: sm1Field
  type(ESMF_Field)       :: sm2Field
  type(ESMF_Field)       :: sm3Field
  type(ESMF_Field)       :: sm4Field
  real, pointer          :: soilm1(:)
  real, pointer          :: soilm2(:)
  real, pointer          :: soilm3(:)
  real, pointer          :: soilm4(:)
  integer                :: t
  integer                :: status
  real                   :: delta1,delta2,delta3,delta4
  real                   :: sm_threshold

  call ESMF_StateGet(LSM_State,"Soil Moisture Layer 1",sm1Field,rc=status)
  call LIS_verify(status,&
       "ESMF_StateSet: Soil Moisture Layer 1 failed in noah36_setsoilm")
  call ESMF_StateGet(LSM_State,"Soil Moisture Layer 2",sm2Field,rc=status)
  call LIS_verify(status,&
       "ESMF_StateSet: Soil Moisture Layer 2 failed in noah36_setsoilm")
  call ESMF_StateGet(LSM_State,"Soil Moisture Layer 3",sm3Field,rc=status)
  call LIS_verify(status,&
       "ESMF_StateSet: Soil Moisture Layer 3 failed in noah36_setsoilm")
  call ESMF_StateGet(LSM_State,"Soil Moisture Layer 4",sm4Field,rc=status)
  call LIS_verify(status,&
       "ESMF_StateSet: Soil Moisture Layer 4 failed in noah36_setsoilm")

  call ESMF_FieldGet(sm1Field,localDE=0,farrayPtr=soilm1,rc=status)
  call LIS_verify(status,&
       "ESMF_FieldGet: Soil Moisture Layer 1 failed in noah36_setsoilm")
  call ESMF_FieldGet(sm2Field,localDE=0,farrayPtr=soilm2,rc=status)
  call LIS_verify(status,&
       "ESMF_FieldGet: Soil Moisture Layer 2 failed in noah36_setsoilm")
  call ESMF_FieldGet(sm3Field,localDE=0,farrayPtr=soilm3,rc=status)
  call LIS_verify(status,&
       "ESMF_FieldGet: Soil Moisture Layer 3 failed in noah36_setsoilm")
  call ESMF_FieldGet(sm4Field,localDE=0,farrayPtr=soilm4,rc=status)
  call LIS_verify(status,&
       "ESMF_FieldGet: Soil Moisture Layer 4 failed in noah36_setsoilm")

  do t=1,LIS_rc%npatch(n,LIS_rc%lsm_index)
     
     sm_threshold = noah36_struc(n)%noah(t)%smcmax - 0.05

     delta1 = soilm1(t)-noah36_struc(n)%noah(t)%smc(1)
     delta2 = soilm2(t)-noah36_struc(n)%noah(t)%smc(2)
     delta3 = soilm3(t)-noah36_struc(n)%noah(t)%smc(3)
     delta4 = soilm4(t)-noah36_struc(n)%noah(t)%smc(4)
     if(noah36_struc(n)%noah(t)%sh2o(1)+delta1.gt.0.10 .and.&
          noah36_struc(n)%noah(t)%sh2o(1)+delta1.lt.&
          sm_threshold) then 
        noah36_struc(n)%noah(t)%sh2o(1) = noah36_struc(n)%noah(t)%sh2o(1)+&
             delta1
        noah36_struc(n)%noah(t)%smc(1) = soilm1(t)
        if(soilm1(t).lt.0) then 
           print*, 'setsoilm1 ',t,soilm1(t)
           stop
        endif
     endif
     if(noah36_struc(n)%noah(t)%sh2o(2)+delta2.gt.0.10 .and.&
          noah36_struc(n)%noah(t)%sh2o(2)+delta2.lt.sm_threshold) then 
        noah36_struc(n)%noah(t)%sh2o(2) = noah36_struc(n)%noah(t)%sh2o(2)+&
             soilm2(t)-noah36_struc(n)%noah(t)%smc(2)
        noah36_struc(n)%noah(t)%smc(2) = soilm2(t)
        if(soilm2(t).lt.0) then 
           print*, 'setsoilm2 ',t,soilm2(t)
           stop
        endif
     endif
     if(noah36_struc(n)%noah(t)%sh2o(3)+delta3.gt.0.10 .and.&
          noah36_struc(n)%noah(t)%sh2o(3)+delta3.lt.sm_threshold) then 
        noah36_struc(n)%noah(t)%sh2o(3) = noah36_struc(n)%noah(t)%sh2o(3)+&
             soilm3(t)-noah36_struc(n)%noah(t)%smc(3)
        noah36_struc(n)%noah(t)%smc(3) = soilm3(t)
        if(soilm3(t).lt.0) then 
           print*, 'setsoilm3 ',t,soilm3(t)
           stop
        endif
     endif
     if(noah36_struc(n)%noah(t)%sh2o(4)+delta4.gt.0.10 .and.&
          noah36_struc(n)%noah(t)%sh2o(4)+delta4.lt.sm_threshold) then 
        noah36_struc(n)%noah(t)%sh2o(4) = noah36_struc(n)%noah(t)%sh2o(4)+&
             soilm4(t)-noah36_struc(n)%noah(t)%smc(4)
        noah36_struc(n)%noah(t)%smc(4) = soilm4(t)
        if(soilm4(t).lt.0) then 
           print*, 'setsoilm4 ',t,soilm4(t)
           stop
        endif
     endif
!     if(noah36_struc(n)%noah(t)%sh2o(1).le.0) then 
!        print*, 'problem1 ',t,noah36_struc(n)%noah(t)%sh2o(1), &
!             noah36_struc(n)%noah(t)%smc(1)
!        stop
!     endif
!     if(noah36_struc(n)%noah(t)%sh2o(2).le.0) then 
!        print*, 'problem2 ',t,noah36_struc(n)%noah(t)%sh2o(2), &
!             noah36_struc(n)%noah(t)%smc(2)
!        stop
!     endif
!     if(noah36_struc(n)%noah(t)%sh2o(3).le.0) then 
!        print*, 'problem3 ',t,noah36_struc(n)%noah(t)%sh2o(3), &
!             noah36_struc(n)%noah(t)%smc(3)
!        stop
!     endif
!     if(noah36_struc(n)%noah(t)%sh2o(4).le.0) then 
!        print*, 'problem4 ',t,noah36_struc(n)%noah(t)%sh2o(4), &
!             noah36_struc(n)%noah(t)%smc(4)
!        stop
!     endif

  enddo
end subroutine noah36_setsoilm

